==> kubernetes-model-1.0.43-sources.jar: io/fabric8/kubernetes/api/model/extensions/DoneableThirdPartyResourceList.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Doneable;

public class DoneableThirdPartyResourceList extends ThirdPartyResourceListFluentImpl<DoneableThirdPartyResourceList> implements Doneable<ThirdPartyResourceList>, ThirdPartyResourceListFluent<DoneableThirdPartyResourceList>{


    private final ThirdPartyResourceListBuilder builder;    private final Function<ThirdPartyResourceList, ThirdPartyResourceList> function;
    public DoneableThirdPartyResourceList ( Function<ThirdPartyResourceList, ThirdPartyResourceList> function){
    this.builder=new ThirdPartyResourceListBuilder(this);this.function=function;
}
    public DoneableThirdPartyResourceList ( ThirdPartyResourceList item,  Function<ThirdPartyResourceList, ThirdPartyResourceList> function){
    this.builder=new ThirdPartyResourceListBuilder(this, item);this.function=function;
}
    public DoneableThirdPartyResourceList ( ThirdPartyResourceList item){
    this.builder=new ThirdPartyResourceListBuilder(this, item);this.function=new Function<ThirdPartyResourceList, ThirdPartyResourceList>() {
    public ThirdPartyResourceList apply(ThirdPartyResourceList item) {
        return item;
    }
}
;
}

    public ThirdPartyResourceList done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/extensions/DoneableThirdPartyResourceList.java <==
package io.fabric8.kubernetes.api.model.extensions;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.KubernetesResourceList;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.Doneable;

public class DoneableThirdPartyResourceList extends ThirdPartyResourceListFluentImpl<DoneableThirdPartyResourceList> implements Doneable<ThirdPartyResourceList>,ThirdPartyResourceListFluent<DoneableThirdPartyResourceList>{


    private final ThirdPartyResourceListBuilder builder;    private final Function<ThirdPartyResourceList, ThirdPartyResourceList> function;
    public DoneableThirdPartyResourceList ( Function<ThirdPartyResourceList, ThirdPartyResourceList> function){
    this.builder=new ThirdPartyResourceListBuilder(this);this.function=function;
}
    public DoneableThirdPartyResourceList ( ThirdPartyResourceList item,  Function<ThirdPartyResourceList, ThirdPartyResourceList> function){
    this.builder=new ThirdPartyResourceListBuilder(this);this.function=function;
}
    public DoneableThirdPartyResourceList ( ThirdPartyResourceList item){
    this.builder=new ThirdPartyResourceListBuilder(this, item);this.function=new Function<ThirdPartyResourceList, ThirdPartyResourceList>() {
    public ThirdPartyResourceList apply(ThirdPartyResourceList item) {
        return item;
    }
}
;
}

    public ThirdPartyResourceList done(){
     return function.apply(builder.build());
}


}
